"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const commander_1 = __importDefault(require("commander"));
const path = __importStar(require("path"));
const webpack_1 = __importDefault(require("webpack"));
const config_1 = require("./config");
function build(dir) {
    const config = config_1.createConfigs(dir);
    const compiler = webpack_1.default(config);
    compiler.run(printResults);
}
function printResults(err, multiStats) {
    process.stdout.write("\n");
    printFiles(multiStats.stats[0], "Client");
    printFiles(multiStats.stats[1], "Server");
    printErrors(multiStats.stats[1]);
    const warnings = printWarnings(multiStats.stats[1]);
    printSummary(multiStats.stats[1], warnings, "Build");
    process.stdout.write("\n");
}
function printErrors(stats) {
    const issues = stats.compilation.errors;
    for (const issue of issues) {
        process.stdout.write(chalk_1.default.red(issue.message));
        process.stdout.write("\n");
    }
}
function printWarnings(stats) {
    const issues = stats.compilation.warnings;
    let warningCount = 0;
    for (const issue of issues) {
        const allWarnings = issue.warning.toString();
        const warnings = allWarnings
            .replace("Error: ", chalk_1.default.grey(""))
            .replace(/\[(\d+), (\d+)\]: (.+)/g, (_substring, start, end, message) => {
            warningCount++;
            const location = chalk_1.default.bold.cyanBright(`${issue.module.resource}(${start},${end})`);
            const entry = chalk_1.default.grey("[wtb]");
            return chalk_1.default.yellow(`${entry} WARNING in ${location}\n      ${message}`);
        });
        process.stdout.write(warnings);
    }
    return warningCount;
}
function printFiles(stats, name) {
    const out = stats.compilation.outputOptions.path;
    const target = stats.compilation.outputOptions.libraryTarget;
    process.stdout.write(`${name} (${target}):\n`);
    for (const chunk of stats.compilation.chunks) {
        for (const file of chunk.files) {
            process.stdout.write(`  ${chalk_1.default.green.italic(path.join(out, file))}\n`);
        }
    }
    process.stdout.write("\n");
}
function printSummary(stats, warningsCount, name) {
    process.stdout.write(`========== ${chalk_1.default.bold(name)}: `);
    printColoredStats(warningsCount, "Warning", chalk_1.default.yellow);
    process.stdout.write(", ");
    printColoredStats(stats.compilation.errors.length, "Error");
    process.stdout.write(" ========== \n");
}
function printColoredStats(stat, name, errorChulk = chalk_1.default.red) {
    const type = stat > 0 ? errorChulk : chalk_1.default.green;
    process.stdout.write(type(`${stat} ${name}`));
    process.stdout.write(type(stat === 1 ? "" : "s"));
}
commander_1.default.command("build <dir>").action(build);
